package net.wanji.databus.vo;

import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.*;
import java.util.List;

/**
 * 控制指令VO
 *
 * @author wuxiaokai
 * @date 2022/11/15 15:05:57
 */
@Data
@ApiModel(value = "ControlCommandVO", description = "相位锁定实体类")
public class ControlCommandVO {

    @ApiModelProperty(value = "路口编号", notes = "路口编号")
    @NotBlank(message = "路口编号不可为空")
    @Pattern(regexp = "^[A-Za-z0-9]{11}$", message = "路口编号只能包含英文、数字，必须11个字符")
    private String crossCode;

    @ApiModelProperty(value = "1是；0否")
    @NotNull(message = "控制类型不可为空,1是；0否")
    @Max(value = 1, message = "控制类型：1是；0否")
    @Min(value = 0, message = "控制类型：1是；0否")
    private Integer command;

    @ApiModelProperty(value = "1全红 2黄闪 3关灯")
    @NotNull(message = "控制类型不可为空,1全红 2黄闪 3关灯")
    private Integer controlType;

    @ApiModelProperty(value = "持续时间")
    private Integer duration;

    @ApiModelProperty(value = "锁定相位列表", notes = "锁定相位列表, 可为空")
    private List<Integer> phaseList;

}
